summaryrefslogtreecommitdiff
path: root/setuptools/tests/test_config.py
diff options
context:
space:
mode:
authorMelissa Li <li.melissa.kun@gmail.com>2021-03-08 03:25:14 -0500
committerMelissa Li <li.melissa.kun@gmail.com>2021-03-08 03:35:19 -0500
commit7129ad1107f7015fe16f275eec17bf36a8badd84 (patch)
treeb33fb6404ed495e6a0d0be296bcf3a9a8c28cb54 /setuptools/tests/test_config.py
parent938a33922c8cba3bbff6dfd1c2f723e5f929d6ce (diff)
downloadpython-setuptools-git-7129ad1107f7015fe16f275eec17bf36a8badd84.tar.gz
Fix formatting of tests and change dash deprecation method name
Diffstat (limited to 'setuptools/tests/test_config.py')
-rw-r--r--setuptools/tests/test_config.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/setuptools/tests/test_config.py b/setuptools/tests/test_config.py
index 1ff5ee41..21f1becd 100644
--- a/setuptools/tests/test_config.py
+++ b/setuptools/tests/test_config.py
@@ -507,10 +507,9 @@ class TestMetadata:
with get_dist(tmpdir):
pass
- def test_dash_to_underscore_warning(self, tmpdir):
- # dash_to_underscore_warning() is a method in setuptools.dist
- # remove this test and method when dash convert to underscore in setup.cfg
- # is no longer supported
+ def test_warn_dash_deprecation(self, tmpdir):
+ # warn_dash_deprecation() is a method in setuptools.dist
+ # remove this test and the method when no longer needed
fake_env(
tmpdir,
'[metadata]\n'
@@ -523,11 +522,12 @@ class TestMetadata:
with pytest.warns(UserWarning, match=msg):
with get_dist(tmpdir) as dist:
metadata = dist.metadata
- assert metadata.author_email == 'test@test.com'
- assert metadata.maintainer_email == 'foo@foo.com'
- def test_uppercase_warning(self, tmpdir):
- # remove this test and the method uppercase_warning() in setuptools.dist
+ assert metadata.author_email == 'test@test.com'
+ assert metadata.maintainer_email == 'foo@foo.com'
+
+ def test_make_option_lowercase(self, tmpdir):
+ # remove this test and the method make_option_lowercase() in setuptools.dist
# when no longer needed
fake_env(
tmpdir,